@@ -50,6 +50,8 @@ class EmergeNeedRootError(EmergeError):
     pass
 
 
+env_terminal_linux = {'TERM':'linux'}
+
 class CommandExecutor(object):
     """
     Запуск программы для объекта Emerge
@@ -60,6 +62,7 @@ class CommandExecutor(object):
         self.cwd = cwd
         self.env = env or dict(os.environ)
         self.env.update({'EINFO_QUIET':'NO'})
+        self.env.update(env_terminal_linux)
         self.cmd = cmd
         self.params = params
         self.child = None
@@ -117,6 +120,7 @@ class EmergeCommand(CommandExecutor):
             }
         default_env.update(os.environ)
         self.env = env or default_env
+        self.env.update(env_terminal_linux)
         self.cwd = cwd
         if logfile:
             self.logfile = logfile
