@@ -165,7 +165,9 @@ class ClUpdateAction(Action):
              {'name': 'update_other:revdev_rebuild',
               'message': __('Checking reverse dependencies'),
               'method': 'Update.revdep_rebuild("revdep-rebuild")',
-              'condition': was_installed('.*', log_names['revdep']),
+              'condition': lambda Get:(Get('cl_update_skip_rb_set') == 'off'
+                    and ClUpdateAction.was_installed('.*', 
+                            ClUpdateAction.log_names['revdep'])()),
               'decoration': 'Update.update_task("%s")' % log_names['revdep']
              },
              {'name': 'update_other:dispatch_conf_end',
@@ -237,6 +239,12 @@ class ClUpdateAction(Action):
                                Get('cl_update_eixupdate_force') != 'skip' or
                                Get('cl_update_eixupdate_force') == 'force'))
              },
+             {'name': 'update_setup_cache',
+              'message': __("Updating the package setup cache"),
+              'method': 'Update.updateSetupCache()',
+              'essential': False,
+              'condition': lambda Get: Get('cl_update_outdate_set') == 'on'
+             },
              {'name': 'sync_reps:cleanpkg',
               'message': __("Removing obsolete distfiles and binary packages"),
               'method': 'Update.cleanpkg()',
@@ -292,3 +300,5 @@ class ClUpdateAction(Action):
          'condition': lambda Get: Get('cl_rebuild_world_set') == 'on'
         },
     ]
+    
+    was_installed = staticmethod(was_installed)
